library(ggplot2)
library(foreign)

kfa <- read.spss("U:/Eigene Dateien/R/kfa.sav", to.data.frame = TRUE, reencode="utf-8")

# Verteilung einer kategorialen Variablen (absolute Hufigkeit)
#ggplot(kfa,aes(x=geschl)) + geom_bar()
ggplot(kfa,aes(x=geschl)) +
  geom_bar(fill="cornflowerblue",colour="blue") +
  labs(x="Geschlecht",y="Hufigkeit")

# Verteilung einer kategorialen Variablen (Prozent)
ggplot(kfa,aes(x=geschl,y=(..count..)*100/sum(..count..))) + 
  geom_bar(fill="cornflowerblue",colour="blue") +
  labs(x="Geschlecht",y="Prozent")

# Verteilung einer kategorialen Variablen (absolute Hufigkeiten als Balkenbeschriftungen)
ggplot(kfa,aes(x=geschl)) +
  geom_bar(fill="lemonchiffon",colour="gray50") +
  labs(x="Geschlecht",y="Hufigkeit") +
  geom_text(stat="bin",mapping=aes(label=..count..),vjust=4,size=4,colour="gray50")

# Median einer metrischen AV fr die Ausgrgungen einer kategorialen UV
ggplot(kfa,aes(x=geschl,y=aergo)) +
  geom_bar(stat="summary",fun.y=median,fill="cornflowerblue") +
  labs(x="Geschlecht",y="Median fr rger")
ggplot(kfa,aes(x=geschl,y=aergo)) +
  stat_summary(geom="bar",fun.y=median,fill="cornflowerblue", colour="blue") +
  labs(x="Geschlecht",y="Median fr rger")

# Mittelwerte und Vertrauensintervalle einer metrischen AV fr die Ausgrgungen einer kategorialen UV
ggplot(kfa,aes(x=geschl,y=aergo)) +
  geom_bar(stat="summary",fun.y=mean,fill="cornflowerblue", colour="blue") +
  geom_errorbar(stat="summary",fun.data=mean_cl_normal,width=0.5, size=1) +
  labs(x="Geschlecht",y="Mittlerer rger\n")
# Geom pointrange statt errorbar
ggplot(kfa,aes(x=geschl,y=aergo)) +
  geom_bar(stat="summary",fun.y=mean,fill="cornflowerblue", colour="blue") +
  geom_pointrange(stat="summary",fun.data=mean_cl_normal,width=0.5, size=1) +
  labs(x="Geschlecht",y="Mittlerer rger\n")

# Messwiederholungsdesign
library(reshape2)
kfa.long <- melt(kfa, id.vars = "fnr", measure.vars = c("aergo","aergm"), variable.name = "kfa")
kfa.long$kfa <- factor(kfa.long$kfa, labels=c("Ohne","Mit"))
ggplot(kfa.long,aes(x=kfa,y=value)) +
  geom_bar(stat="summary", fun.y=mean, fill="cornflowerblue", colour="blue") +
  geom_errorbar(stat="summary", fun.data=mean_cl_normal, width=0.5, size=1) +
  labs(x="KFA", y="Mittlerer rger\n")

# Gruppiertes Balkendiagramm (Split-Plot - Design)
library(reshape2)
kfa.long <- melt(kfa, id.vars = c("fnr","geschl"), measure.vars = c("aergo","aergm"), variable.name = "kfa")
kfa.long$kfa <- factor(kfa.long$kfa, labels=c("Ohne","Mit"))
ggplot(kfa.long,aes(kfa,value,fill=geschl)) + geom_bar(stat="summary", fun.y=mean, position=position_dodge(), colour="black") + 
  geom_errorbar(stat="summary", fun.data=mean_cl_normal, position = position_dodge(width=0.9), width=0.5, size=1) +
  labs(x="KFA", y="Mittlerer rger\n", fill="Geschlecht") + scale_fill_manual(values=c("mediumorchid", "lightsteelblue3"))
# Diagonale Linien aus den Legendenelementen entfernen
ggplot(kfa.long,aes(kfa,value,fill=geschl)) +
  geom_bar(stat="summary", fun.y=mean, position=position_dodge()) + 
  geom_bar(stat="summary", fun.y=mean, position=position_dodge(), colour="black", show_guide=FALSE) + 
  geom_errorbar(stat="summary", fun.data=mean_cl_normal, position = position_dodge(width=0.9), width=0.5, size=1) +
  labs(x="KFA", y="Mittlerer rger\n", fill="Geschlecht") + scale_fill_manual(values=c("mediumorchid", "lightsteelblue3"))

