load("U:\\Eigene Dateien\\R\\ggg.RData")
library(ggplot2)

# Bivariates Streudiagramm von Gewicht und Gre
sd <- ggplot(ggg, aes(gre, gewicht))
sd + geom_point(colour="red", size=3)
sd + geom_point(colour="red", size=3) + labs(x = "Gre", y = "Gewicht")
sd + geom_smooth() + geom_point(colour="red", size=3) + labs(x = "Gre", y = "Gewicht")
# Glttungsschicht mit linearer Anpassung und falscher vertikaler Position
sd + geom_point(colour="red", size=3) + geom_smooth(method = "lm") + labs(x = "Gre", y = "Gewicht")
# Mit Titel
sd + geom_smooth(method = "lm") + geom_point(colour="red", size=3) + labs(x = "Gre", y = "Gewicht") + ggtitle("Regression von Gewicht\nauf Gre und Geschlecht")

# Direkte Modifikation eines ggplot2-Objekts
sdo <- sd + geom_point(colour="red", size=3)
str(sdo)
sdo$labels$x<-"Gre"; sdo$labels$y<-"Gewicht"; sdo

# Individuelle Skala
sd <- ggplot(ggg, aes(gre, gewicht))
sd + geom_point(colour="red", size=3) + scale_x_continuous("Gre", limits=c(150, 190), breaks=seq(150, 190, by=5), minor_breaks = NULL)

# Gruppiertes Streudiagramm mit Gewicht, Gre und Geschlecht
gsd <- ggplot(ggg, aes(gre, gewicht, colour=geschlecht))
gsd + geom_smooth(method="lm") + geom_point(size=3) + labs(x="Gre", y="Gewicht", colour="Geschlecht")
# Vorschlag Field (2012, S. 141)
gsd + geom_point(size=3) + geom_smooth(method="lm", aes(fill=geschlecht),alpha=0.1) + labs(x="Gre", y="Gewicht", colour="Geschlecht")

# Ohne Legende
gsd + geom_smooth(method="lm") + geom_point(size=3) + labs(x="Gre", y="Gewicht") + theme(legend.position="none")

# Gemeinsame Anpasssungsfunktion fr alle Gruppen
gsd <- ggplot(ggg, aes(gre, gewicht, colour=geschlecht))
gsd <- gsd + geom_smooth(method="lm", aes(group=1), show_guide=FALSE) + geom_point(size=3) + labs(x="Gre", y="Gewicht", colour="Geschlecht")
gsd


# Geschlechtsgruppen dargestellt durch indivduelle Farben mit dem voreingestellten Symbol 16 (gefllter Kreis)
gsd <- ggplot(ggg,aes(gre,gewicht,colour=geschlecht))
gsd <- gsd+geom_point(size=5)+labs(x="Gre",y="Gewicht")
gsd + scale_colour_manual(name="Geschlecht", values=c("violet", "lightcyan4"))

# Geschlechtsgruppen dargestellt durch die voreingestellten Symbole (16,17)
gsd <- ggplot(ggg,aes(gre,gewicht,shape=geschlecht))
gsd + geom_point(size=5, colour="brown1")+labs(x="Gre",y="Gewicht", shape="Geschlecht")
# gsd + scale_shape_manual(name="Geschlecht",values=c(16,17))

# Geschlechtsgruppen dargestellt durch alternative Symbole (15,18)
gsd <- ggplot(ggg,aes(gre,gewicht,shape=geschlecht))
gsd <- gsd+geom_point(size=5,colour="brown1")+labs(x="Gre",y="Gewicht")
gsd + scale_shape_manual(name="Geschlecht",values=c(15,18))

# Geschlechtsgruppen dargestellt durch indivduelle Farben und die voreingestellten Symbole (16,17)
gsd <- ggplot(ggg,aes(gre,gewicht,colour=geschlecht,shape=geschlecht))
gsd <- gsd+geom_point(size=5)+labs(x="Gre",y="Gewicht",shape="Geschlecht")
gsd + scale_colour_manual(name="Geschlecht",values=c("violet","lightcyan4"))

# Individuelle Farben und Formen bei Symbolen mit separater Randfarbe
gsd <- ggplot(ggg,aes(gre,gewicht,fill=geschlecht,shape=geschlecht))
gsd <- gsd+geom_point(size=5)+labs(x="Gre",y="Gewicht", shape="Geschlecht", fill="Geschlecht")
gsd + scale_fill_manual(values=c("violet","lightcyan4")) + scale_shape_manual(values=c(21,24))


# Diagrammaufbau mit qplot()
qplot(gewicht, gre, data = ggg) + geom_smooth(method="lm")

# Beschriftete Datenpunkte, keine Legende zum Text-Geom
ggplot(ggg, aes(gre, gewicht, colour=geschlecht)) + geom_point(size=3) + labs(x="Gre", y="Gewicht", colour="Geschlecht") + geom_text(aes(y=gewicht-1, label=rownames(ggg)), show_guide=FALSE)

# Facetten
ggplot(ggg, aes(gre, gewicht)) + geom_point() + facet_wrap(~ geschlecht)
